@@ -123,14 +123,14 @@ class Parser(object):
     def scanner(self):
         # type: () -> Any
         if hasattr(self.loader, 'typ'):
-            self.loader.scanner
+            return self.loader.scanner
         return self.loader._scanner
 
     @property
     def resolver(self):
         # type: () -> Any
         if hasattr(self.loader, 'typ'):
-            self.loader.resolver
+            return self.loader.resolver
         return self.loader._resolver
 
     def check_event(self, *choices):
@@ -434,9 +434,16 @@ class Parser(object):
             )
             self.state = self.parse_flow_sequence_first_entry
         elif self.scanner.check_token(FlowMappingStartToken):
+            pt = self.scanner.peek_token()
             end_mark = self.scanner.peek_token().end_mark
             event = MappingStartEvent(
-                anchor, tag, implicit, start_mark, end_mark, flow_style=True
+                anchor,
+                tag,
+                implicit,
+                start_mark,
+                end_mark,
+                flow_style=True,
+                comment=pt.comment,
             )
             self.state = self.parse_flow_mapping_first_key
         elif block and self.scanner.check_token(BlockSequenceStartToken):
@@ -553,7 +560,6 @@ class Parser(object):
 
     def parse_block_mapping_key(self):
         # type: () -> Any
-        # print('>>>> tk', type(self), next_token, getattr(next_token, 'comment', None))
         if self.scanner.check_token(KeyToken):
             token = self.scanner.get_token()
             token.move_comment(self.scanner.peek_token())
@@ -583,8 +589,6 @@ class Parser(object):
         if self.scanner.check_token(ValueToken):
             token = self.scanner.get_token()
             # value token might have post comment move it to e.g. block
-            # pt = self.scanner.peek_token()
-            # print('pt', pt)
             if self.scanner.check_token(ValueToken):
                 token.move_comment(self.scanner.peek_token())
             else:
@@ -598,7 +602,11 @@ class Parser(object):
                 self.state = self.parse_block_mapping_key
                 comment = token.comment
                 if comment is None:
-                    comment = self.scanner.peek_token().comment
+                    token = self.scanner.peek_token()
+                    comment = token.comment
+                    if comment:
+                        token._comment = [None, comment[1]]
+                        comment = [comment[0], None]
                 return self.process_empty_scalar(token.end_mark, comment=comment)
         else:
             self.state = self.parse_block_mapping_key
